@@ -11,14 +11,17 @@ Astro::Coord::ECI::TLE::Set - Represent a set of data for the same ID.
 
  # Get orbital data on the International Space Station and
  # related NASA stuff. 
- my $st = Astro::SpaceTrack->new();
- my $rslt = $st->spaceflight('-all');
+ my $st = Astro::SpaceTrack->new(
+     username => $me,
+     password => $secret,
+ );
+ my $rslt = $st->retrieve( qw{ -last5 25544 } );
  $rslt->is_success
      or die "Unable to get data: ", $rslt->status_line;
  
- # We aggregate the data because NASA provides multiple sets
- # of orbital elements for each body. The Set object will
- # select the correct one for the given time.
+ # We aggregate the data because we retrieved the last five orbital
+ # elements for the body. The Set object will select the correct one for
+ # the given time.
  my @sats = Astro::Coord::ECI::TLE::Set->aggregate (
      Astro::Coord::ECI::TLE->parse ($rslt->content));
  my $now = time ();
@@ -140,14 +143,13 @@ our @CARP_NOT = qw{
     Astro::Coord::ECI
 };
 
-our $VERSION = '0.116_01';
+our $VERSION = '0.117_01';
 
 use constant ERR_NOCURRENT => <<eod;
 Error - Can not call %s because there is no current member. Be
         sure you called add() after instantiating or calling clear().
 eod
 
-
 =item $set = Astro::Coord::ECI::TLE::Set->new ()
 
 This method instantiates a new set. Any arguments are passed to the
@@ -167,7 +169,6 @@ sub new {
     return $self;
 }
 
-
 =item $set->add ($member ...);
 
 This method adds members to the set. The initial member may be any
@@ -227,7 +228,6 @@ eod
     return $self;
 }
 
-
 =item @sets = Astro::Coord::ECI::TLE::Set->aggregate ($tle ...);
 
 This method aggregates the given Astro::Coord::ECI::TLE objects into
@@ -286,7 +286,6 @@ sub aggregate {
     return @rslt;
 }
 
-
 =item $set->can ($method);
 
 This method checks to see if the object can execute the given method.
@@ -310,7 +309,6 @@ sub can {
     };
 }
 
-
 =item $set->clear ();
 
 This method removes all members from the set, allowing it to be
@@ -416,7 +414,6 @@ sub represents {
     return $self->{current}->represents($class);
 }
 
-
 =item $set->select ($time);
 
 This method selects the member object that best represents the given
@@ -453,7 +450,6 @@ eod
     return $self->{current};
 }
 
-
 =item $set->set ($name => $value ...);
 
 This method iterates over the individual name-value pairs. If the name
@@ -478,7 +474,6 @@ sub set {
     return $self;
 }
 
-
 =item $set->set_all ($name => $value ...);
 
 This method sets the given attribute values on all members of the set.
@@ -576,7 +571,6 @@ sub validate {
     return $self->validate($opt, @args);
 }
 
-
 #	The AUTOLOAD routine does not define methods, it simply
 #	simulates them. This is because there is no good way to
 #	get rid of the routines if we end up representing a
@@ -623,8 +617,10 @@ __END__
 
 =head1 BUGS
 
-Bugs can be reported to the author by mail, or through
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues/>.
+Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
+L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -632,7 +628,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2020 by Thomas R. Wyant, III
+Copyright (C) 2005-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
